@@ -19,8 +19,8 @@
 ;; URL:              https://github.com/meedstrom/el-job
 ;; Created:          2024-10-30
 ;; Keywords:         processes
-;; Package-Version: 20260128.2225
-;; Package-Revision: f6df73974171
+;; Package-Version: 20260222.1009
+;; Package-Revision: 5af4975c1764
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -42,7 +42,7 @@
 
 (require 'el-job-ng)
 
-(defconst el-job-internal-version 105)
+(defconst el-job-internal-version 107)
 
 ;; FIXME: It seems to print the nil message during work
 ;;;###autoload
@@ -92,7 +92,7 @@ something with the return value."
      :inputs list
      :callback (lambda (outputs)
                  (setq result outputs)))
-    (unless (el-job-ng-await-or-die id 86400)
+    (unless (el-job-ng-await-or-die id 86400 "Running el-job-parallel-mapcar")
       (error "el-job-ng-parallel-mapcar: Timed out (hung for 24 hours): %S" fn))
     result))
 
